@@ -29,3 +29,13 @@ class Messages:
         if files:
             body['files'] = files
         return await self._driver._execute_api_post(self._SEND.format(workspace_id), body=body)
+
+    _ADD_REACTION = 'workspace/items/{}/conversation/items/{}/message/items/{}/reaction/items/{}'
+    async def add_reaction(self, workspace_id, conversation_id, message_id, reaction_name):
+        return await self._driver._execute_api_post(self._ADD_REACTION.format(workspace_id, conversation_id, message_id, reaction_name), {})
+
+    _REMOVE_REACTION = 'workspace/items/{}/conversation/items/{}/message/items/{}/reaction/items/{}'
+    async def remove_reaction(self, workspace_id, conversation_id, message_id, reaction_name):
+        return await self._driver._execute_api_delete(self._REMOVE_REACTION.format(workspace_id, conversation_id, message_id, reaction_name))
+
+
